package com.alterdekim.hearthhack.component;

import lombok.extern.slf4j.Slf4j;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;

import java.io.IOException;
import java.net.ServerSocket;
import java.net.Socket;
import java.util.LinkedList;
import java.util.List;

@Slf4j
@Component
public class GameServer {

    private final int port = 3724;

    private ServerSocket serverSocket;

    private List<GameConnection> connections;

    @Scheduled(fixedDelay = 5000)
    private void start() {
        try {
            this.connections = new LinkedList<>();
            this.serverSocket = new ServerSocket(this.port);
            while(true) {
                Socket client = this.serverSocket.accept();
                log.info("New WOW Connection Established From {}", client.getInetAddress().toString());
                GameConnection c = new GameConnection(client);
                this.connections.add(c);
                c.start();
            }
        } catch (IOException e) {
            log.error(e.getMessage());
        }
    }

    public void stopListening() {
        connections.forEach(GameConnection::stopListeningAndDisconnect);
        try {
            serverSocket.close();
        } catch (IOException e) {
            log.error(e.getMessage());
        }
    }

    public void removeConnection(TcpConnection c) {
        connections.remove(c);
    }
}
